summaryrefslogtreecommitdiffstats
path: root/host/include
diff options
context:
space:
mode:
Diffstat (limited to 'host/include')
-rw-r--r--host/include/uhd/types/tune_result.hpp6
-rw-r--r--host/include/uhd/usrp/CMakeLists.txt2
2 files changed, 4 insertions, 4 deletions
diff --git a/host/include/uhd/usrp/CMakeLists.txt b/host/include/uhd/usrp/CMakeLists.txt
index 9140d98ca..23758041c 100644
--- a/host/include/uhd/usrp/CMakeLists.txt
+++ b/host/include/uhd/usrp/CMakeLists.txt
@@ -27,7 +27,7 @@ INSTALL(FILES
#### dboard headers ###
dboard_base.hpp
dboard_id.hpp
- dboard_interface.hpp
+ dboard_iface.hpp
dboard_manager.hpp
### usrp headers ###
diff --git a/host/include/uhd/types/tune_result.hpp b/host/include/uhd/types/tune_result.hpp
index 31742e1af..c428a7692 100644
--- a/host/include/uhd/types/tune_result.hpp
+++ b/host/include/uhd/types/tune_result.hpp
@@ -26,15 +26,15 @@ namespace uhd{
* The tune result struct holds result of a 2-phase tuning:
* The struct hold the result of tuning the dboard as
* the target and actual intermediate frequency.
* The struct hold the result of tuning the DDC/DUC as
* the target and actual digital converter frequency.
* It also tell us weather or not the spectrum is inverted.
*/
struct UHD_API tune_result_t{
double target_inter_freq;
double actual_inter_freq;
- double target_dxc_freq;
- double actual_dxc_freq;
+ double target_dsp_freq;
+ double actual_dsp_freq;
bool spectrum_inverted;
tune_result_t(void);
};
@@ -26,15 +26,15 @@ namespace uhd{
* The struct hold the result of tuning the dboard as
* the target and actual intermediate frequency.
- * The struct hold the result of tuning the DDC/DUC as
+ * The struct hold the result of tuning the DSP as
* the target and actual digital converter frequency.
* It also tell us weather or not the spectrum is inverted.